@@ -3,7 +3,7 @@
 ================================================================================
 
 	mingus - Music theory Python package, Bar class
-	Copyright (C) 2008, Bart Spaans
+	Copyright (C) 2008-2009, Bart Spaans
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -153,6 +153,14 @@ in the Bar"""
 					max = note
 		return (min, max)
 
+        def space_left(self):
+                """Returns the space left on the Bar."""
+                return self.length  - self.current_beat
+
+        def value_left(self):
+                """Returns the value left on the Bar."""
+                return 1.0 / self.space_left()
+
 	def augment(self):
 		"""Calls augment on the NoteContainers in Bar."""
 		for cont in self.bar:
