@@ -3,7 +3,7 @@
 ================================================================================
 
 	mingus - Music theory Python package, extra package
-	Copyright (C) 2008, Bart Spaans
+	Copyright (C) 2008-2009, Bart Spaans
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 """
 
 import LilyPond
+from tunings import StringTuning
 
-__all__ = ["LilyPond", "fft", "MusicXML", "tunings", "tablature"]
 
+__all__ = ['LilyPond', 'fft', 'MusicXML', 'tunings', 'tablature', 'StringTuning']
