@@ -3,7 +3,7 @@
 ================================================================================
 
 	mingus - Music theory Python package, midi package
-	Copyright (C) 2008, Bart Spaans
+	Copyright (C) 2008-2009, Bart Spaans
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,5 +21,7 @@
 ================================================================================
 
 """
+from Sequencer import Sequencer
+from SequencerObserver import SequencerObserver
 
-__all__ = ["Sequencer", "MidiFileIn", "MidiFileOut", "MidiTrack", "fluidsynth"]
+__all__ = ["Sequencer", "SequencerObserver", "MidiFileIn", "MidiFileOut", "MidiTrack", "fluidsynth"]
