@@ -3,7 +3,7 @@
 ================================================================================
 
 	mingus - Music theory Python package, FluidSynth support
-	Copyright (C) 2008, Bart Spaans
+	Copyright (C) 2008-2009, Bart Spaans
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -73,10 +73,10 @@ sf2 file. Retuns True on success, False on failure."""
 
         # Implement Sequencer's interface
 
-        def play_event(self, channel, note, velocity):
+        def play_event(self, note, channel, velocity):
 		self.fs.noteon(channel, note, velocity)
 
-        def stop_event(self, channel, note):
+        def stop_event(self, note, channel):
 		self.fs.noteoff(channel, note)
 
         def cc_event(self, channel, control, value):
