@@ -58,6 +58,7 @@ import test_Suite
 import test_fft
 import test_tablature
 import test_tunings
+import test_MusicXML
 
 # See run_fluidsynth_tests.py for FluidSynth audio tests 
 # See run_lilypond_tests.py to generate some pdf's
@@ -69,7 +70,7 @@ core = [test_notes, test_diatonic, test_intervals, test_chords,
 containers = [test_Note, test_NoteContainers, test_Instrument,
               test_Bar, test_Track, test_Composition, test_Suite]
 
-extra = [test_fft, test_tunings, test_tablature]
+extra = [test_fft, test_tunings, test_tablature, test_MusicXML]
 
 # Run all tests
 suite = unittest.TestSuite([ x.suite() for x in core + containers + extra ])
